==> qgis-plugins-6.0.tar.gz: tablemanager/tableManager_plugin.py <==
# -*- coding: utf-8 -*-
#-----------------------------------------------------------
# 
# Table Manager
# Copyright (C) 2008-2011 Borys Jurgiel
# 
#-----------------------------------------------------------
# 
# licensed under the terms of GNU GPL 2
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along
# with this program; if not, print to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
#---------------------------------------------------------------------

from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *

import resources_rc
import tableManager_gui

class tableManager:

 def __init__(self, iface):
  self.iface = iface
  #i18n
  pluginPath = QFileInfo(QgsApplication.qgisUserDbFilePath()).path()+"/python/plugins/tablemanager"
  localeName = QLocale.system().name()
  if QFileInfo(pluginPath).exists():
    self.localePath = pluginPath+"/i18n/tablemanager_" + localeName + ".qm"
  if QFileInfo(self.localePath).exists():
    self.translator = QTranslator()
    self.translator.load(self.localePath)
    if qVersion() > '4.3.3':
      QCoreApplication.installTranslator(self.translator)  


  # ----------------------------------------- #
 #def setCurrentTheme(self, theThemeName):
    #""" Set icons to the current theme """
    #self.action.setIcon(self.getThemeIcon("tableManagerIcon-.png"))


  ## ----------------------------------------- #
 #def getThemeIcon(self, theName):
    #""" get the icon from the best available theme """
    #myCurThemePath = QgsApplication.activeThemePath() + "/plugins/" + theName;
    #myDefThemePath = QgsApplication.defaultThemePath() + "/plugins/" + theName;
    #myQrcPath = ":/plugins/installer/" + theName;
    #if QFile.exists(myCurThemePath):
      #return QIcon(myCurThemePath)
    #elif QFile.exists(myDefThemePath):
      #return QIcon(myDefThemePath)
    #elif QFile.exists(myQrcPath):
      #return QIcon(myQrcPath)
    #else:
      #return QIcon()


 def initGui(self):
  # create action 
  #self.action = QAction(self.getThemeIcon("tableManagerIcon.png"), QCoreApplication.translate('TableManager','Table manager'), self.iface.mainWindow())
  self.action = QAction(QIcon(':/plugins/tableManager/icons/tableManagerIcon.png'), QCoreApplication.translate('TableManager','Table manager'), self.iface.mainWindow())
  self.action.setWhatsThis(QCoreApplication.translate('TableManager','Manages attribute table structure'))
  QObject.connect(self.action, SIGNAL('triggered()'), self.run)
  # add toolbar button and menu item
  self.iface.addToolBarIcon(self.action)
  self.iface.addPluginToMenu('&Table', self.action)


 def unload(self):
  # remove the plugin menu item and icon
  self.iface.removePluginMenu('&Table',self.action)
  self.iface.removeToolBarIcon(self.action)


 def run(self):
  # create and show a configuration dialog or something similar
  layer = self.iface.activeLayer()
  if layer == None or layer.type() != layer.VectorLayer:
    QMessageBox.warning(self.iface.mainWindow(), QCoreApplication.translate('TableManager','Table manager'), QCoreApplication.translate('TableManager','Please select a vector layer'))
  elif layer.isEditable():
    QMessageBox.warning(self.iface.mainWindow(), QCoreApplication.translate('TableManager','Table manager'), QCoreApplication.translate('TableManager','The selected layer is currently in editing mode.\nPlease exit this mode before managing the table.'))
  else:
    dialoga = tableManager_gui.TableManager(self.iface)
    dialoga.exec_()

==> qgis-plugins-6.5.tar.gz: tablemanager/tableManager_plugin.py <==
# -*- coding: utf-8 -*-
#-----------------------------------------------------------
# 
# Table Manager
# Copyright (C) 2008-2011 Borys Jurgiel
# 
#-----------------------------------------------------------
# 
# licensed under the terms of GNU GPL 2
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along
# with this program; if not, print to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
#---------------------------------------------------------------------

from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *

import resources_rc
import tableManager_gui
import os.path

class tableManager:

 def __init__(self, iface):
  self.iface = iface
  #i18n
  pluginPath = QFileInfo(os.path.realpath(__file__)).path()  # patch by Régis Haubourg
  localeName = QLocale.system().name()
  if QFileInfo(pluginPath).exists():
    self.localePath = pluginPath+"/i18n/tablemanager_" + localeName + ".qm"
  if QFileInfo(self.localePath).exists():
    self.translator = QTranslator()
    self.translator.load(self.localePath)
    if qVersion() > '4.3.3':
      QCoreApplication.installTranslator(self.translator)  


  # ----------------------------------------- #
 #def setCurrentTheme(self, theThemeName):
    #""" Set icons to the current theme """
    #self.action.setIcon(self.getThemeIcon("tableManagerIcon-.png"))


  ## ----------------------------------------- #
 #def getThemeIcon(self, theName):
    #""" get the icon from the best available theme """
    #myCurThemePath = QgsApplication.activeThemePath() + "/plugins/" + theName;
    #myDefThemePath = QgsApplication.defaultThemePath() + "/plugins/" + theName;
    #myQrcPath = ":/plugins/installer/" + theName;
    #if QFile.exists(myCurThemePath):
      #return QIcon(myCurThemePath)
    #elif QFile.exists(myDefThemePath):
      #return QIcon(myDefThemePath)
    #elif QFile.exists(myQrcPath):
      #return QIcon(myQrcPath)
    #else:
      #return QIcon()


 def initGui(self):
  # create action 
  #self.action = QAction(self.getThemeIcon("tableManagerIcon.png"), QCoreApplication.translate('TableManager','Table manager'), self.iface.mainWindow())
  self.action = QAction(QIcon(':/plugins/tableManager/icons/tableManagerIcon.png'), QCoreApplication.translate('TableManager','Table manager'), self.iface.mainWindow())
  self.action.setWhatsThis(QCoreApplication.translate('TableManager','Manages attribute table structure'))
  QObject.connect(self.action, SIGNAL('triggered()'), self.run)
  # add toolbar button and menu item
  self.iface.addToolBarIcon(self.action)
  self.iface.addPluginToMenu('&Table', self.action)


 def unload(self):
  # remove the plugin menu item and icon
  self.iface.removePluginMenu('&Table',self.action)
  self.iface.removeToolBarIcon(self.action)


 def run(self):
  # create and show a configuration dialog or something similar
  layer = self.iface.activeLayer()
  if layer == None or layer.type() != layer.VectorLayer:
    QMessageBox.warning(self.iface.mainWindow(), QCoreApplication.translate('TableManager','Table manager'), QCoreApplication.translate('TableManager','Please select a vector layer'))
  elif layer.isEditable():
    QMessageBox.warning(self.iface.mainWindow(), QCoreApplication.translate('TableManager','Table manager'), QCoreApplication.translate('TableManager','The selected layer is currently in editing mode.\nPlease exit this mode before managing the table.'))
  else:
    dialoga = tableManager_gui.TableManager(self.iface)
    dialoga.exec_()
